pype32.directories.ExportTableEntry

Package pype32 :: Module directories :: Class ExportTableEntry |
[hide private]
[frames] | no frames]

# Class ExportTableEntry

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 ExportTableEntry

ExportTableEntry object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) A class representation of a `` structure. | source code
__repr__(self) repr(x) | source code
getType(self) Returns consts.EXPORT_TABLE_ENTRY. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
ExportTableEntry |
parse(readDataInstance) Returns a new ExportTableEntry object. | source code

Instance Variables | [hide private]
| ordinal DWORD ordinal.
| functionRva DWORD functionRva.
| nameOrdinal WORD nameOrdinal.
| nameRva DWORD nameRva.
| name String name.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
A class representation of a `` structure. Parameters: `shouldPack` (bool) - (Optional) If set to c{True}, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### getType(self) | source code
Returns consts.EXPORT_TABLE_ENTRY. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType

### parse(readDataInstance) Static Method | source code
Returns a new ExportTableEntry object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a ExportTableEntry object. Returns: ExportTableEntry A new ExportTableEntry object.